aboutsummaryrefslogtreecommitdiff
path: root/include/sg_lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/sg_lib.h')
-rw-r--r--include/sg_lib.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/sg_lib.h b/include/sg_lib.h
index 8e2f541d..0e2d842c 100644
--- a/include/sg_lib.h
+++ b/include/sg_lib.h
@@ -317,10 +317,10 @@ char * sg_get_pdt_str(int pdt, int buff_len, char * buff);
/* Some lesser used PDTs share a lot in common with a more used PDT.
* Examples are PDT_ADC decaying to PDT_TAPE and PDT_ZBC to PDT_DISK.
- * If such a lesser used 'pdt' is given to this function, then it will
- * return the more used PDT (i.e. "decays to"); otherwise 'pdt' is returned.
- * Valid for 'pdt' 0 to 31, for other values returns 0. */
-int sg_lib_pdt_decay(int pdt);
+ * If such a lesser used 'dev_pdt' is given to this function, then it will
+ * return the more used PDT (i.e. "decays to"); otherwise 'dev_pdt' is
+ * returned. Valid for 'pdt' 0 to 31, for other values returns 0. */
+int sg_lib_pdt_decay(int dev_pdt);
/* Yield string associated with transport protocol identifier (tpi). Returns
* 'buff'. If 'tpi' out of range yields "bad tpi" string. */